==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/foundation/NSCompoundPredicate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 3.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("Foundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSCompoundPredicate/*</name>*/ 
    extends /*<extends>*/NSPredicate/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSCompoundPredicatePtr extends Ptr<NSCompoundPredicate, NSCompoundPredicatePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSCompoundPredicate.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSCompoundPredicate() {}
    protected NSCompoundPredicate(SkipInit skipInit) { super(skipInit); }
    public NSCompoundPredicate(NSCompoundPredicateType type, NSArray<NSPredicate> subpredicates) { super((SkipInit) null); initObject(init(type, subpredicates)); }
    public NSCompoundPredicate(NSCoder coder) { super((SkipInit) null); initObject(initWithCoder$(coder)); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "compoundPredicateType")
    public native NSCompoundPredicateType getCompoundPredicateType();
    @Property(selector = "subpredicates")
    public native NSArray<NSPredicate> getSubpredicates();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "initWithType:subpredicates:")
    protected native @Pointer long init(NSCompoundPredicateType type, NSArray<NSPredicate> subpredicates);
    @Method(selector = "initWithCoder:")
    protected native @Pointer long initWithCoder$(NSCoder coder);
    @Method(selector = "andPredicateWithSubpredicates:")
    public static native NSCompoundPredicate createAndPredicate(NSArray<NSPredicate> subpredicates);
    @Method(selector = "orPredicateWithSubpredicates:")
    public static native NSCompoundPredicate createOrPredicate(NSArray<NSPredicate> subpredicates);
    @Method(selector = "notPredicateWithSubpredicate:")
    public static native NSCompoundPredicate createNotPredicate(NSPredicate predicate);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/foundation/NSCompoundPredicate.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.foundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.security.*;
import org.robovm.apple.dispatch.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("Foundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/NSCompoundPredicate/*</name>*/ 
    extends /*<extends>*/NSPredicate/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class NSCompoundPredicatePtr extends Ptr<NSCompoundPredicate, NSCompoundPredicatePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(NSCompoundPredicate.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public NSCompoundPredicate() {}
    protected NSCompoundPredicate(Handle h, long handle) { super(h, handle); }
    protected NSCompoundPredicate(SkipInit skipInit) { super(skipInit); }
    @Method(selector = "initWithType:subpredicates:")
    public NSCompoundPredicate(NSCompoundPredicateType type, NSArray<NSPredicate> subpredicates) { super((SkipInit) null); initObject(init(type, subpredicates)); }
    @Method(selector = "initWithCoder:")
    public NSCompoundPredicate(NSCoder coder) { super((SkipInit) null); initObject(init(coder)); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "compoundPredicateType")
    public native NSCompoundPredicateType getCompoundPredicateType();
    @Property(selector = "subpredicates")
    public native NSArray<NSPredicate> getSubpredicates();
    @Property(selector = "supportsSecureCoding")
    public static native boolean supportsSecureCoding();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "initWithType:subpredicates:")
    protected native @Pointer long init(NSCompoundPredicateType type, NSArray<NSPredicate> subpredicates);
    @Method(selector = "initWithCoder:")
    protected native @Pointer long init(NSCoder coder);
    @Method(selector = "andPredicateWithSubpredicates:")
    public static native NSCompoundPredicate createAndPredicate(NSArray<NSPredicate> subpredicates);
    @Method(selector = "orPredicateWithSubpredicates:")
    public static native NSCompoundPredicate createOrPredicate(NSArray<NSPredicate> subpredicates);
    @Method(selector = "notPredicateWithSubpredicate:")
    public static native NSCompoundPredicate createNotPredicate(NSPredicate predicate);
    /*</methods>*/
}
